==> haskell-non-negative-0.1.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: non-negative
version: 0.1.2
id: non-negative-0.1.2-6U9lrly4BunGPtdZnLSwcy
key: non-negative-0.1.2-6U9lrly4BunGPtdZnLSwcy
license: LicenseRef-GPL
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
author: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://code.haskell.org/~thielema/non-negative/
synopsis: Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.
category: Math
abi: 8624453cc9111872f30fb90c66ed9057
exposed: True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper
hidden-modules: Numeric.NonNegative.ChunkyPrivate
import-dirs: /usr/lib/ghc-8.4.2/site-local/non-negative-0.1.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/non-negative-0.1.2
hs-libraries: HSnon-negative-0.1.2-6U9lrly4BunGPtdZnLSwcy
depends:
    semigroups-0.18.4-8TzSEFpYt1WDcfY361NEhv
    utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW
    QuickCheck-2.11.3-4bkq8vcRuH33iMSCEtmKx6 base-4.11.1.0
abi-depends: semigroups-0.18.4-8TzSEFpYt1WDcfY361NEhv=de35bd6c21af2947fea51000f88c89bb
             utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW=01882dd84317759c82599f3c49dc23bd
             QuickCheck-2.11.3-4bkq8vcRuH33iMSCEtmKx6=329f1c9cae18d78e8febe9289607fdb9
             base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-non-negative/html/non-negative.haddock
haddock-html: /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-non-negative-0.1.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: non-negative
version: 0.1.2
id: non-negative-0.1.2-CzJkHCeQuFC7hHKT455tko
key: non-negative-0.1.2-CzJkHCeQuFC7hHKT455tko
license: LicenseRef-GPL
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
author: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://code.haskell.org/~thielema/non-negative/
synopsis: Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.
category: Math
abi: f91dc0f84c6f7d7c2500a825a332cb5a
exposed: True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper
hidden-modules: Numeric.NonNegative.ChunkyPrivate
import-dirs: /usr/lib/ghc-8.4.3/site-local/non-negative-0.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/non-negative-0.1.2
hs-libraries: HSnon-negative-0.1.2-CzJkHCeQuFC7hHKT455tko
depends:
    utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
abi-depends: utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW=bc9afceb753d627ae3b4fbbea4555a5b
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-non-negative/html/non-negative.haddock
haddock-html: /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
